@@ -1,4 +1,3 @@
-from logging import NullHandler
 import logging
 from ploomber.dag.DAG import DAG
 from ploomber.dag.DAGConfigurator import DAGConfigurator
@@ -7,16 +6,15 @@ from ploomber.env.decorators import load_env, with_env
 from ploomber.placeholders.SourceLoader import SourceLoader
 from ploomber.jupyter import _load_jupyter_server_extension
 
-
-__version__ = '0.7.1'
+__version__ = '0.7.2'
 
 # Set default logging handler to avoid "No handler found" warnings.
 
-logging.getLogger(__name__).addHandler(NullHandler())
+logging.getLogger(__name__).addHandler(logging.NullHandler())
 
-
-__all__ = ['DAG', 'Env', 'SourceLoader', 'load_env', 'with_env',
-           'DAGConfigurator']
+__all__ = [
+    'DAG', 'Env', 'SourceLoader', 'load_env', 'with_env', 'DAGConfigurator'
+]
 
 
 def _jupyter_server_extension_paths():
