@@ -1,3 +1,4 @@
+import os
 import logging
 import sys
 import importlib
@@ -28,13 +29,24 @@ def process_arg(s):
 
 class CustomParser(argparse.ArgumentParser):
     """
-    A custom ArgumentParser that keeps track of arguments
-    """
-    DEFAULT_ENTRY_POINT = 'pipeline.yaml'
+    Most of our CLI commands operate on entry points, the CLI signature is
+    defined by a few static arguments (they always appear when doing
+    ploomber {cmd} --entry-point {entry} --help) and dynamic arguments
+    (they are generated depending on the entry point). To support this, we
+    have this CustomParser that distinguishes between static and dynamic args
 
+    Once initialized, static args must be added using this as a context
+    manager, only after this has happened, other arguments can be added using
+    parser.add_argument.
+    """
     def __init__(self, *args, **kwargs):
+        self.DEFAULT_ENTRY_POINT = os.environ.get(
+            'ENTRY_POINT') or 'pipeline.yaml'
+
         self.static_args = []
         self.finished_static_api = False
+        self.in_context = False
+        self.finished_init = False
         super().__init__(*args, **kwargs)
 
         self.add_argument('--log',
@@ -45,9 +57,13 @@ class CustomParser(argparse.ArgumentParser):
 
         self.add_argument('--entry-point',
                           '-e',
-                          help='Entry point(DAG), defaults to pipeline.yaml',
+                          help='Entry point(DAG), defaults to pipeline.yaml. '
+                          'Replaced if there is an ENTRY_POINT env '
+                          'variable defined',
                           default=self.DEFAULT_ENTRY_POINT)
 
+        self.finished_init = True
+
     def parse_entry_point_value(self):
         index = None
 
@@ -66,10 +82,19 @@ class CustomParser(argparse.ArgumentParser):
 
     def add_argument(self, *args, **kwargs):
         if not self.finished_static_api:
-            self.static_args.extend([process_arg(arg) for arg in args])
+            if not self.in_context and self.finished_init:
+                raise RuntimeError('Cannot aadd arguments until the static '
+                                   'API has been declared')
+            else:
+                self.static_args.extend([process_arg(arg) for arg in args])
         return super().add_argument(*args, **kwargs)
 
-    def done_with_static_api(self):
+    def __enter__(self):
+        self.in_context = True
+        return self
+
+    def __exit__(self, exc_type, exc_value, exc_traceback):
+        self.in_context = False
         self.finished_static_api = True
 
 
@@ -165,6 +190,8 @@ def _add_args_from_callable(parser, callable_):
     parameters with default values as optional and parameters with no defaults
     as mandatory. Adds descriptions from parsing the callable's docstring
 
+    It also adds the description from the docstring, if any
+
     Returns parsed args: required (list) and defaults (dict)
     """
     doc = _parse_doc(callable_.__doc__)
@@ -180,6 +207,13 @@ def _add_args_from_callable(parser, callable_):
                             help=get_desc(doc, arg),
                             **add_argument_kwargs(params, arg))
 
+    if doc['summary']:
+        # summary should return the first line only, but we do this just in
+        # case the numpydoc implementation changes
+        summary = '\n'.join(doc['summary'])
+        desc = parser.description
+        parser.description = '{}. Docstring: {}'.format(desc, summary)
+
     return required, defaults
 
 
