@@ -90,7 +90,8 @@ class PloomberContentsManager(TextFileContentsManager):
                         self.dag.render()
 
                     tuples = [(resolve_path(path_parent, t.source.loc), t)
-                              for t in self.dag.values()]
+                              for t in self.dag.values()
+                              if t.source.loc is not None]
                     self.dag_mapping = {
                         t[0]: t[1]
                         for t in tuples if t[0] is not None
