@@ -3,10 +3,10 @@ Create Tasks from dictionaries
 """
 from copy import copy
 from pathlib import Path
-from collections.abc import MutableMapping, Iterable, Mapping
+from collections.abc import MutableMapping, Mapping
 
 from ploomber import tasks, products
-from ploomber.util.util import load_dotted_path
+from ploomber.util.util import load_dotted_path, _make_iterable
 from ploomber.spec import validate
 
 suffix2taskclass = {
@@ -29,7 +29,15 @@ class TaskSpec(MutableMapping):
         # initialie required elements
         self.data['class'] = get_class_obj(self.data)
         # in task specs, we assume source is always a path to a file
-        self.data['source'] = Path(self.data['source'])
+
+        source_loader = meta['source_loader']
+
+        if source_loader:
+            # if there is a source loader, use it...
+            self.data['source'] = source_loader[self.data['source']]
+        else:
+            # otherwise just initialize a path
+            self.data['source'] = Path(self.data['source'])
 
     def validate(self):
         if 'upstream' not in self.data:
@@ -167,7 +175,7 @@ def init_product(task_dict, meta, task_class, root_path):
         CLASS = getattr(products, meta_product_default_class)
     else:
         raise ValueError('Could not determine a product class for task: '
-                         '"{}". Add an explicity value in the '
+                         '"{}". Add an explicit value in the '
                          '"product_class" key or provide a default value in '
                          'meta.product_default_class by setting the '
                          'key to the applicable task class'.format(task_dict))
@@ -191,15 +199,6 @@ def init_product(task_dict, meta, task_class, root_path):
                      **kwargs)
 
 
-def _make_iterable(o):
-    if isinstance(o, Iterable) and not isinstance(o, str):
-        return o
-    elif o is None:
-        return []
-    else:
-        return [o]
-
-
 def resolve_product(product_raw, relative_to, class_):
     if class_ != products.File:
         return product_raw
